==> infrahub_server-1.2.0rc0.tar.gz: infrahub_server-1.2.0rc0/backend/infrahub/computed_attribute/triggers.py <==
from infrahub.trigger.models import BuiltinTriggerDefinition, EventTrigger, ExecuteWorkflow
from infrahub.workflows.catalogue import (
    COMPUTED_ATTRIBUTE_REMOVE_PYTHON,
    COMPUTED_ATTRIBUTE_SETUP,
    COMPUTED_ATTRIBUTE_SETUP_PYTHON,
)

TRIGGER_COMPUTED_ATTRIBUTE_PYTHON_SETUP_BRANCH = BuiltinTriggerDefinition(
    name="computed-attribute-python-setup-on-branch-creation",
    previous_names={"Trigger-schema-update-event"},
    description="Trigger actions on branch create event",
    trigger=EventTrigger(events={"infrahub.branch.created"}),
    actions=[
        ExecuteWorkflow(
            name=COMPUTED_ATTRIBUTE_SETUP_PYTHON.name,
            parameters={
                "branch_name": "{{ event.resource['infrahub.branch.name'] }}",
                "trigger_updates": False,
                "context": {
                    "__prefect_kind": "json",
                    "value": {"__prefect_kind": "jinja", "template": "{{ event.payload['context'] | tojson }}"},
                },
            },
        )
    ],
)

TRIGGER_COMPUTED_ATTRIBUTE_PYTHON_SETUP_COMMIT = BuiltinTriggerDefinition(
    name="computed-attribute-python-setup-on-commit",
    description="Trigger actions on branch create event",
    trigger=EventTrigger(events={"infrahub.repository.update_commit"}),
    actions=[
        ExecuteWorkflow(
            name=COMPUTED_ATTRIBUTE_SETUP_PYTHON.name,
            parameters={
                "branch_name": "{{ event.resource['infrahub.branch.name'] }}",
                "commit": "{{ event.payload['commit'] }}",
                "context": {
                    "__prefect_kind": "json",
                    "value": {"__prefect_kind": "jinja", "template": "{{ event.payload['context'] | tojson }}"},
                },
            },
        )
    ],
)

TRIGGER_COMPUTED_ATTRIBUTE_PYTHON_CLEAN_BRANCH = BuiltinTriggerDefinition(
    name="computed-attribute-python-cleanup-on-branch-deletion",
    description="Trigger actions on branch delete event",
    trigger=EventTrigger(events={"infrahub.branch.deleted"}),
    actions=[
        ExecuteWorkflow(
            name=COMPUTED_ATTRIBUTE_REMOVE_PYTHON.name,
            parameters={
                "branch_name": "{{ event.resource['infrahub.branch.name'] }}",
                "context": {
                    "__prefect_kind": "json",
                    "value": {"__prefect_kind": "jinja", "template": "{{ event.payload['context'] | tojson }}"},
                },
            },
        )
    ],
)

TRIGGER_COMPUTED_ATTRIBUTE_ALL_SCHEMA = BuiltinTriggerDefinition(
    name="computed-attribute-all-setup-on-schema-update",
    trigger=EventTrigger(events={"infrahub.schema.update"}),
    actions=[
        ExecuteWorkflow(
            name=COMPUTED_ATTRIBUTE_SETUP.name,
            parameters={
                "branch_name": "{{ event.resource['infrahub.branch.name'] }}",
                "context": {
                    "__prefect_kind": "json",
                    "value": {"__prefect_kind": "jinja", "template": "{{ event.payload['context'] | tojson }}"},
                },
            },
        ),
        ExecuteWorkflow(
            name=COMPUTED_ATTRIBUTE_SETUP_PYTHON.name,
            parameters={
                "branch_name": "{{ event.resource['infrahub.branch.name'] }}",
                "context": {
                    "__prefect_kind": "json",
                    "value": {"__prefect_kind": "jinja", "template": "{{ event.payload['context'] | tojson }}"},
                },
            },
        ),
    ],
)

==> infrahub_server-1.2.4.tar.gz: infrahub_server-1.2.4/backend/infrahub/computed_attribute/triggers.py <==
from infrahub.events.branch_action import BranchDeletedEvent
from infrahub.events.repository_action import CommitUpdatedEvent
from infrahub.events.schema_action import SchemaUpdatedEvent
from infrahub.trigger.models import BuiltinTriggerDefinition, EventTrigger, ExecuteWorkflow
from infrahub.workflows.catalogue import (
    COMPUTED_ATTRIBUTE_SETUP_JINJA2,
    COMPUTED_ATTRIBUTE_SETUP_PYTHON,
)

TRIGGER_COMPUTED_ATTRIBUTE_PYTHON_SETUP_COMMIT = BuiltinTriggerDefinition(
    name="computed-attribute-python-setup-on-commit",
    trigger=EventTrigger(events={CommitUpdatedEvent.event_name}),
    actions=[
        ExecuteWorkflow(
            workflow=COMPUTED_ATTRIBUTE_SETUP_PYTHON,
            parameters={
                "branch_name": "{{ event.resource['infrahub.branch.name'] }}",
                "commit": "{{ event.payload['commit'] }}",
                "event_name": "{{ event.event }}",
                "context": {
                    "__prefect_kind": "json",
                    "value": {"__prefect_kind": "jinja", "template": "{{ event.payload['context'] | tojson }}"},
                },
            },
        )
    ],
)

TRIGGER_COMPUTED_ATTRIBUTE_ALL_SCHEMA = BuiltinTriggerDefinition(
    name="computed-attribute-setup-all",
    trigger=EventTrigger(events={SchemaUpdatedEvent.event_name, BranchDeletedEvent.event_name}),
    actions=[
        ExecuteWorkflow(
            workflow=COMPUTED_ATTRIBUTE_SETUP_JINJA2,
            parameters={
                "branch_name": "{{ event.resource['infrahub.branch.name'] }}",
                "event_name": "{{ event.event }}",
                "context": {
                    "__prefect_kind": "json",
                    "value": {"__prefect_kind": "jinja", "template": "{{ event.payload['context'] | tojson }}"},
                },
            },
        ),
        ExecuteWorkflow(
            workflow=COMPUTED_ATTRIBUTE_SETUP_PYTHON,
            parameters={
                "branch_name": "{{ event.resource['infrahub.branch.name'] }}",
                "event_name": "{{ event.event }}",
                "context": {
                    "__prefect_kind": "json",
                    "value": {"__prefect_kind": "jinja", "template": "{{ event.payload['context'] | tojson }}"},
                },
            },
        ),
    ],
)
